# DarContact: Ethan Galstad <nagios@nagios.org>

%define logmsg logger -t %{name}/rpm

Summary: Host/service/network monitoring program.
Name: nagios
Version: 1.1
Release: 1
License: GPL
Group: Applications/System
URL: http://www.nagios.org/

Packager: Dag Wieers <dag@wieers.com>
Vendor: Dag Apt Repository, http://dag.wieers.com/apt/

Source: http://prdownloads.sourceforge.net/nagios/%{name}-%{version}.tar.gz
### FIXME: Make embedded perl build
Patch0: nagios-1.1-embedperl.patch
BuildRoot: %{_tmppath}/root-%{name}-%{version}
Prefix: %{_prefix}

BuildRequires: gd-devel, zlib-devel, libpng-devel, libjpeg-devel
Obsoletes: %{name}-www

%description
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is
designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various services
that you specify.

The actual service checks are performed by separate "plugin" programs
which return the status of the checks to Nagios. The plugins are
located in the nagios-plugins package.

%package devel
Summary: Header files, libraries and development documentation for %{name}.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files, static libraries and development
documentation for %{name}. If you like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup
%patch0 -b .orig

%build
### FIXME: Disabled embedded perl on RH80 and RH9 to fix segfaults
%configure \
	--datadir="%{_datadir}/nagios" \
	--libexecdir="%{_libdir}/nagios/plugins" \
	--localstatedir="%{_localstatedir}/log/nagios" \
	--sbindir="%{_libdir}/nagios/cgi" \
	--sysconfdir="%{_sysconfdir}/nagios" \
	--with-cgiurl="/nagios/cgi-bin" \
	--with-command-user="apache" \
	--with-command-grp="apache" \
	--with-file-perfdata \
	--with-gd-lib="%{_libdir}" \
	--with-gd-inc="%{_includedir}" \
	--with-init-dir="%{_initrddir}" \
	--with-htmurl="/nagios" \
	--with-lockfile="%{_localstatedir}/run/nagios.pid" \
	--with-nagios-user="nagios" \
	--with-nagios-grp="nagios" \
%{?rh73:--enable-embedded-perl} \
	--with-template-objects \
	--with-template-extinfo
%{__make} %{?_smp_mflags} all
%{__make} %{?_smp_mflags} -C contrib

%install
%{__rm} -rf %{buildroot}
%{__install} -d -m0775 %{buildroot}%{_localstatedir}/spool/nagios
%{__install} -d -m0755 %{buildroot}%{_includedir}/nagios \
			%{buildroot}%{_libdir}/nagios/cgi \
			%{buildroot}%{_sysconfdir}/logrotate.d \
			%{buildroot}%{_sysconfdir}/httpd/conf.d \
			%{buildroot}%{_sysconfdir}/nagios/private \
			%{buildroot}%{_libdir}/nagios/plugins/eventhandlers
%{__make} install DESTDIR="%{buildroot}" INSTALL_OPTS="" COMMAND_OPTS=""
%{__make} install-daemoninit DESTDIR="%{buildroot}" INSTALL_OPTS="" COMMAND_OPTS="" INIT_OPTS=""

%{__perl} -pi -e 's#/var/log/nagios/rw#%{_localstatedir}/spool/nagios#' sample-config/nagios.cfg
%{__perl} -pi -e 's#\@sysconfdir@/resource.cfg#\@sysconfdir@/private/resource.cfg#' sample-config/nagios.cfg 
%{__install} -m0664 sample-config/{cgi,nagios}.cfg %{buildroot}%{_sysconfdir}/nagios/
%{__install} -m0640 sample-config/resource.cfg %{buildroot}%{_sysconfdir}/nagios/private/
%{__install} -m0664 sample-config/template-object/{checkcommands,contactgroups,contacts,dependencies,escalations,hostgroups,hosts,minimal,misccommands,services,timeperiods}.cfg %{buildroot}%{_sysconfdir}/nagios/
%{__install} -m0644 common/locations.h %{buildroot}%{_includedir}/nagios
%{__install} -m0644 contrib/htaccess.sample %{buildroot}%{_sysconfdir}/httpd/conf.d/nagios.conf

%makeinstall -C contrib INSTALL="install" INSTALL_OPTS="" COMMAND_OPTS="" CGIDIR="%{buildroot}%{_libdir}/nagios/cgi"
%{__mv} -f %{buildroot}%{_libdir}/nagios/cgi/convertcfg %{buildroot}%{_libdir}/nagios/
%{__mv} -f %{buildroot}%{_libdir}/nagios/cgi/mini_epn %{buildroot}%{_bindir}

%{__perl} -pi -e 's#/usr/local/nagios/var/rw#%{_localstatedir}/spool/nagios#' contrib/eventhandlers/*
%{__perl} -pi -e 's#/usr/local/nagios/libexec/eventhandlers#%{_libdir}/nagios/plugins/eventhandlers#' contrib/eventhandlers/*
%{__perl} -pi -e 's#/usr/local/nagios/test/var#%{_localstatedir}/log/nagios#' contrib/eventhandlers/*
%{__cp} -afv contrib/eventhandlers/* %{buildroot}%{_libdir}/nagios/plugins/eventhandlers/

%pre
if ! /usr/bin/id nagios ; then
	/usr/sbin/useradd -r -d %{_localstatedir}/log/nagios -s /bin/sh -c "nagios" nagios || \
		%logmsg "Unexpected error adding user \"nagios\". Aborting install process."
fi

%post
/sbin/chkconfig --add nagios

if ! /usr/bin/id -Gn apache |/bin/grep -q nagios ; then 
	/usr/sbin/usermod -G nagios apache &>/dev/null
	%logmsg "User \"apache\" added to group \"nagios\" so sending commands to Nagios from the command CGI is possible."
fi

if [ -f %{_sysconfdir}/httpd/conf/httpd.conf ]; then
	if ! grep -q "Include */nagios.conf" %{_sysconfdir}/httpd/conf/httpd.conf; then
		echo "# Include %{_sysconfdir}/httpd/conf.d/nagios.conf" >> %{_sysconfdir}/httpd/conf/httpd.conf
#		/sbin/service httpd restart
	fi
fi

%preun
if [ "$1" == "0" ]; then
	/sbin/service nagios stop &>/dev/null
	/sbin/chkconfig --del nagios
fi

%postun
if [ "$1" == "0" ]; then
	/usr/sbin/userdel nagios || %logmsg "User \"nagios\" could not be deleted."
	/usr/sbin/groupdel nagios || %logmsg "Group \"nagios\" could not be deleted."
fi
/sbin/service nagios condrestart &>/dev/null || :

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc Changelog INSTALLING LICENSE README UPGRADING pkg/rpm/nagios.logrotate
%dir %{_sysconfdir}/nagios/
%config(noreplace) %{_sysconfdir}/nagios/*.cfg
%config(noreplace) %{_sysconfdir}/httpd/conf.d/nagios.conf
%config %{_initrddir}/nagios
%{_bindir}/*
%{_libdir}/nagios/
%{_datadir}/nagios/
%defattr(-, root, nagios, 0755)
%config(noreplace) %{_sysconfdir}/nagios/private/
%defattr(-, nagios, nagios, 0755)
%{_localstatedir}/log/nagios/
%defattr(-, nagios, apache, 2755)
%{_localstatedir}/spool/nagios/

%files devel
%defattr(-, root, root, 0755)
%{_includedir}/nagios/

%changelog
* Sat Jul 12 2003 Dag Wieers <dag@wieers.com> - 1.1-1
- Disabled embedded perl.

* Wed Jun 04 2003 Dag Wieers <dag@wieers.com> - 1.1-0
- Updated to release 1.1.

* Tue Jun 03 2003 Dag Wieers <dag@wieers.com> - 1.0-1
- Don't restart webserver.

* Sun Feb 16 2003 Dag Wieers <dag@wieers.com> - 1.0-0
- Initial package. (using DAR)
